@@ -19,7 +19,15 @@ require 5.000; use strict 'vars', 'refs', 'subs';
 
 BEGIN {
     use File::Copy; # for copying generated files
-    use Glade::PerlRun qw( :METHODS :VARS ); # Our run-time utilities and vars
+    use Glade::PerlRun qw( :METHODS :VARS !&_); 
+                                            # Our run-time methods and vars
+                                            # but not &_ since we do that ourselves.
+    use File::Basename qw( basename );      # in check_gettext_strings
+    use Text::Wrap     qw( wrap $columns ); # in write_gettext_strings
+    use subs        qw(
+                        _
+                        start_checking_gettext_strings
+                    );
     use vars        qw( 
                         @ISA 
                         %fields %stubs
@@ -53,7 +61,7 @@ BEGIN {
                         $first_form
                       );
     $PACKAGE      = __PACKAGE__;
-    $VERSION        = q(0.51);
+    $VERSION        = q(0.52);
     @VARS         = qw( 
                         $VERSION
                         $AUTHOR
@@ -84,8 +92,10 @@ BEGIN {
                         $first_form
                     );
     @METHODS      = qw( 
-                        D_ 
-                        S_ 
+                        _
+                        S_
+                        D_
+                        start_checking_gettext_strings
                         missing_handler
                     );
     $subs =             '';
@@ -99,7 +109,7 @@ BEGIN {
     # Tell interpreter who we are inheriting from
     @ISA          = qw( Exporter Glade::PerlRun );
     # These symbols (globals and functions) are always exported
-    @EXPORT       = qw( );
+    @EXPORT       = qw(  );
     # Optionally exported package symbols (globals and functions)
     @EXPORT_OK    = ( @VARS, @METHODS );
     # Tags (groups of symbols) to export        
@@ -132,6 +142,112 @@ sub new {
     return $self;
 }
 
+#===============================================================================
+#=========== Gettext Utilities                                              ====
+#===============================================================================
+# These are defined within a no-warning block to avoid warnings about redefining
+# They override the subs in Glade::PerlRun during your development
+{   
+    local $^W = 0;
+    eval "sub _ {_check_gettext('__', \@_);}";
+}
+# Translate into source language
+sub S_ { _check_gettext('__S', @_)}
+
+# Translate into diagnostics language
+sub D_ { _check_gettext('__D', @_)}
+
+sub start_checking_gettext_strings {
+    # Ask for translations to be checked and stored if missing
+    my ($class, $key, $file) = @_;
+    $I18N->{($key || '__')}{'__SAVE_MISSING'} = ($file || "&STDOUT");
+}
+
+sub stop_checking_gettext_strings {
+    # Ask for translation checking to be stopped
+    my ($class, $key) = @_;
+    undef $I18N->{($key || '__')}{'__SAVE_MISSING'};
+}
+
+sub _check_gettext {
+    # If check_gettext_strings() has been called and there is no translation
+    # we store the original string for later output by write_gettext_strings
+    my ($key, $text, $depth) = @_;
+    $depth ||= 1;
+    if (defined $I18N->{$key}{$text}) {
+        return $I18N->{$key}{$text};
+    } else {
+        if ($I18N->{$key}{'__SAVE_MISSING'}) {
+            my $called_at = 
+                basename((caller $depth)[1]). ":".(caller $depth)[2];
+            unless ($I18N->{$key}{'__MISSING_STRINGS'}{$text} && 
+                $I18N->{$key}{'__MISSING_STRINGS'}{$text} =~ / $called_at /) {
+                $I18N->{$key}{'__MISSING_STRINGS'}{$text} .= " $called_at ";
+            }
+        }
+        return $text;
+    }
+}
+
+sub write_missing_gettext_strings {
+    # Write out the strings that need to be translated in .pot format
+    my ($class, $key, $file, $no_header, $copy_to) = @_;
+    $key ||= "__";
+    my ($string, $called_at);
+    my $me = __PACKAGE__."->write_translatable_strings";
+    my $saved = $I18N->{$key}{'__MISSING_STRINGS'};
+    $key  ||= "__";
+    $file ||= $I18N->{$key}{'__SAVE_MISSING'};
+    return unless keys %$saved;
+    open POT, ">$file" or 
+        die sprintf(("error %s - can't open file '%s' for output"),
+                $me, $file);
+    my $date = `date +"%Y-%m-%d %H:%M%z"`; chomp $date;
+    my $year = `date +"%Y"`; chomp $year;
+    # Print header
+    print POT "# ".sprintf(S_("These are strings that had no gettext translation in '%s'"), $key)."\n";
+    print POT "# ".sprintf(S_("Automatically generated by %s"),__PACKAGE__)."\n";
+    print POT "# ".S_("Date")." ".`date`;
+    print POT "# ".sprintf(S_("Run from class %s in file %s"), $class->PACKAGE, (caller 0)[1])."\n";
+    unless ($no_header && $no_header eq "NO_HEADER") {
+        print POT "
+# SOME DESCRIPTIVE TITLE.
+# Copyright (C) $year ORGANISATION
+# ".$class->AUTHOR.",
+#
+# , fuzzy
+msgid \"\"
+msgstr \"\"
+\"Project-Id-Version:  ".$class->PACKAGE." ".$class->{'VERSION'}."\\n\"
+\"POT-Creation-Date: $date\\n\"
+\"PO-Revision-Date:  YEAR-MO-DA HO:MI+ZONE\\n\"
+\"Last-Translator:  ".$class->AUTHOR."\\n\"
+\"Language-Team:  LANGUAGE \<LL\@li.org\>\\n\"
+\"MIME-Version:  1.0\\n\"
+\"Content-Type: text/plain; charset=CHARSET\\n\"
+\"Content-Transfer-Encoding:  ENCODING\\n\"
+
+# Generic replacement
+msgid  \"\%s\"
+msgstr \"\%s\"
+
+";  }
+
+    # Print definition for each string
+    foreach $string (%$saved) {
+        next unless $string and $saved->{$string};
+        print POT wrap("#", "#",$saved->{$string}), "\n";
+        if ($string =~ s/\n/\\n\"\n\"/g) {$string = "\"\n\"".$string}
+        print POT "msgid  \"$string\"\n";
+        if ($copy_to && $copy_to eq 'COPY_TO') {
+            print POT "msgstr \"$string\"\n\n";
+        } else {
+            print POT "msgstr \"\"\n\n";
+        }
+    }
+    close POT;
+}
+
 #===============================================================================
 #=========== Utilities to write output file                         ============
 #===============================================================================
@@ -140,7 +256,7 @@ sub Stop_Writing_to_File { shift->Write_to_File('-1') }
 sub Write_to_File {
     my ($class) = @_;
     my $me = "$class->Write_to_File";
-    my $filename = $main::Glade_Perl_Generate_options->write_source;
+    my $filename = $Glade_Perl->{'options'}->write_source;
     if (fileno UI or fileno SIGS or fileno SUBCLASS or $class->Building_UI_only) {
         # Files are already open or we are not writing source
         if ($class->Writing_to_File) {
@@ -150,7 +266,7 @@ sub Write_to_File {
                 close SIGS;
                 $class->diag_print (2, "%s- Closing output file in %s",
                     $indent, $me);
-                $main::Glade_Perl_Generate_options->write_source(undef);
+                $Glade_Perl->{'options'}->write_source(undef);
             } else {
                 $class->diag_print (2, "%s- Already writing to %s in %s",
                     $indent, $class->Writing_to_File, $me);
@@ -165,24 +281,24 @@ sub Write_to_File {
     } elsif ($filename && ($filename ne '-1') ) {
         # We want to write source
         if ($filename eq 'STDOUT') {
-            $main::Glade_Perl_Generate_options->write_source('>&STDOUT');
+            $Glade_Perl->{'options'}->write_source('>&STDOUT');
         }
         $class->diag_print (2, "%s- Writing %s source to %s - in %s", 
             $indent, 'UI  ', $filename, $me);
         open UI,     ">$filename" or 
-            die sprintf(S_(
+            die sprintf((
                 "error %s - can't open file '%s' for output"),
                 $me, $filename);
         $class->diag_print (2, "%s- Writing %s source to %s - in %s", 
             $indent, 'SUBS', $filename, $me);
         open SIGS,     ">$filename" or 
-            die sprintf(S_(
+            die sprintf((
                 "error %s - can't open file '%s' for output"),
                 $me, $filename);
         $class->diag_print (2, "%s- Writing %s source to %s - in %s", 
             $indent, 'SUBCLASS', $filename, $me);
         open SUBCLASS,     ">$filename" or 
-            die sprintf(S_(
+            die sprintf((
                 "error %s - can't open file '%s' for output"),
                 $me, $filename);
         UI->autoflush(1);
@@ -211,8 +327,8 @@ sub add_to_UI {
     }
     unless ($tofileonly) {
         eval $expr or 
-            ($@ && die  "\n\nin $me\n\t".D_("while trying to eval").
-                "'$expr'\n\t".D_("FAILED with Eval error")." '$@'\n");
+            ($@ && die  "\n\nin $me\n\twhile trying to eval".
+                "'$expr'\n\tFAILED with Eval error '$@'\n");
     }
     if ($mydebug) {
         $expr =~ s/\%/\%\%/g;
@@ -245,10 +361,8 @@ sub perl_preamble {
     my ($class, $package, $project, $proto, $name, $oktoedit) = @_;
     my $localtime = localtime;
     my $warning_string;
-# FIXME I18N
     return 
-"
-#==============================================================================
+"#==============================================================================
 #=== ".S_("This is the")." '$name' class                              
 #==============================================================================
 package $name;
@@ -261,13 +375,12 @@ require 5.000; use strict \'vars\', \'refs\', \'subs\';
 $project->{'copying'} $project->{'author'}
 #
 #==============================================================================
-# ".S_("This perl source file was automatically generated by")." $class
-# ".S_("from Glade file")." $project->{'glade_filename'}
-# ".S_("Date")." $project->{'date'}
+# ".S_("This perl source file was automatically generated by")." 
+# $class ".S_("version")." $VERSION - $DATE
+# ".S_("Copyright")." (c) ".S_("Author")." $AUTHOR
 #
-# $class       - ".S_("version")." $VERSION
-# ".S_("Copyright")." (c) ".S_("Date")." $DATE
-# ".S_("Author")." $AUTHOR
+# ".S_("from Glade file")." $project->{'glade_filename'}
+# $project->{'date'}
 #==============================================================================
 
 ";
@@ -281,8 +394,7 @@ sub perl_about {
     $logo .= '/' if $logo;
     $logo .= $project->{'logo'};
 
-    if ($main::Glade_Perl_Generate_options->{'allow_gnome'}) {
-# FIXME I18N
+    if ($Glade_Perl->{'options'}->{'allow_gnome'}) {
         return
 "sub about_Form {
 ${indent}my (\$class) = \@_;
@@ -310,9 +422,9 @@ ${indent}\$ab->position('mouse' );
 ${indent}\$ab->set_policy(1, 1, 0 );
 ${indent}\$ab->set_modal(1 );
 ${indent}\$ab->show;
-}";
+} # ".S_("End of sub")." about_Form";
+
     } else {
-# FIXME I18N
        return
 "sub about_Form {
 ${indent}my (\$class) = \@_;
@@ -330,7 +442,7 @@ ${indent}${indent}\"Gtk-Perl \"._(\"version\").\": \$Gtk::VERSION\\n\".
 ${indent}${indent}_(\"run from file\").\": \$name\";
 ${indent}__PACKAGE__->message_box(\$message, _(\"About\").\" \\u\".__PACKAGE__, [_('Dismiss'), _('Quit Program')], 1,
 ${indent}${indent}\"$logo\", 'left' );
-}";
+} # ".S_("End of sub")." about_Form";
     }
 }
 
@@ -338,7 +450,6 @@ sub perl_signal_handler {
     my ($class, $handler, $type) = @_;
     my ($body);
     if ($type eq 'SIGS') {
-# FIXME I18N
         $body = "
 ${indent}my (\$class, \$data, \$object, \$instance, \$event) = \@_;
 ${indent}my \$me = __PACKAGE__.\"->$handler\";
@@ -348,7 +459,7 @@ ${indent}my \$form = \$__PACKAGE__::all_forms->{\$instance};
 ${indent}# ".S_("REPLACE the line below with the actions to be taken when").
     " __PACKAGE__.\"->$handler.\" is called
 ${indent}__PACKAGE__->show_skeleton_message(\$me, \\\@_, ".
-    "__PACKAGE__, \"\$Glade::PerlRun::pixmaps_directory/$Glade_Perl->{'logo'}\");
+    "__PACKAGE__, \"\$Glade::PerlRun::pixmaps_directory/$Glade_Perl->{'options'}{'logo'}\");
 
 ";
     } elsif ($type eq 'SUBCLASS') {
@@ -358,10 +469,10 @@ ${indent}my \$me = __PACKAGE__.\"->$handler\";
 ${indent}# ".S_("Get ref to hash of all widgets on our form")."
 ${indent}my \$form = \$__PACKAGE__::all_forms->{\$instance};
 
-${indent}# ".S_("REPLACE the line below with the actions to be taken when").
+${indent}# ".S_("REPLACE the lines below with the actions to be taken when").
     " __PACKAGE__.\"->$handler.\" is called
 #${indent}__PACKAGE__->show_skeleton_message(\$me, \\\@_, ".
-    "__PACKAGE__, \"\$Glade::PerlRun::pixmaps_directory/$Glade_Perl->{'logo'}\");
+    "__PACKAGE__, \"\$Glade::PerlRun::pixmaps_directory/$Glade_Perl->{'options'}{'logo'}\");
 ${indent}shift->SUPER::$handler(\@_);
 
 ";
@@ -373,7 +484,7 @@ ${indent}my \$me = __PACKAGE__.\"->$handler\";
 ${indent}# ".S_("REPLACE the line below with the actions to be taken when").
     " __PACKAGE__.\"->$handler.\" is called
 ${indent}__PACKAGE__->show_skeleton_message(\$me, \\\@_, ".
-    "__PACKAGE__, \"\$Glade::PerlRun::pixmaps_directory/$Glade_Perl->{'logo'}\");
+    "__PACKAGE__, \"\$Glade::PerlRun::pixmaps_directory/$Glade_Perl->{'options'}{'logo'}\");
 
 ";
     }
@@ -397,7 +508,7 @@ ${indent}\$self->CLASS_HIERARCHY(\$self->FORM->{'__WH'});
 ${indent}\$self->WIDGET_HIERARCHY(\$self->FORM->{'__CH'});
 ${indent}\$__PACKAGE__::all_forms->{\$self->INSTANCE} = \$self->FORM;
 ${indent}return \$self;
-}";
+} # ".S_("End of sub")." new";
 }
 
 sub perl_doc {
@@ -469,12 +580,12 @@ sub write_UI {
     unless (fileno UI) {            # ie user has supplied a filename
         # Open UI for output unless the filehandle is already open 
         open UI,     ">".($proto->{'UI_filename'})    or 
-            die sprintf(S_(
+            die sprintf((
                 "error %s - can't open file '%s' for output"),
                 $me, $proto->{'UI_filename'});
         $class->diag_print (2, "%s- Writing %s source to %s - in %s", 
             $indent, 'UI  ', $proto->{'UI_filename'}, $me);
-        if ($main::Glade_Perl_Generate_options->autoflush) {
+        if ($Glade_Perl->{'options'}->autoflush) {
             UI->autoflush(1);
         }
     }
@@ -488,16 +599,16 @@ sub write_UI {
         }
         # FIXME Now generate different source code for each user choice
         push @code, $class->perl_AUTOLOAD_top(
-            $Glade_Perl, $proto, $form, $permitted_stubs)."\n";
+            $Glade_Perl->{'options'}, $proto, $form, $permitted_stubs)."\n";
 #print "Working on form '$form'\n";
 #use Data::Dumper; print Dumper($forms);
 #print "'",join("'\n", @{$forms->{$form}{'UI_Strings'}}),"'\n";
         $UI_String = join("\n", @{$forms->{$form}{'UI_Strings'}});
         push @code, $UI_String;
-        push @code, $class->perl_constructor_bottom($Glade_Perl, $form);
+        push @code, $class->perl_constructor_bottom($Glade_Perl->{'options'}, $form);
         push @code, "\n\n\n\n\n\n\n\n";
     }
-    push @code, $class->perl_doc($Glade_Perl, $proto->{'UI_class'}, $first_form);
+    push @code, $class->perl_doc($Glade_Perl->{'options'}, $proto->{'UI_class'}, $first_form);
 
     print UI "#!/usr/bin/perl -w\n";
     print UI "#\n# ".S_("This is the (re)generated UI construction class.")."\n";
@@ -528,10 +639,10 @@ sub perl_AUTOLOAD_top {
     $init_string .= "${indent}\$class->load_translations('$project->{'name'}');
 ${indent}# ".S_("You can use the line below to load a test .mo file before it is")."
 ${indent}# ".S_("installed in the normal place")." (eg /usr/local/share/locale/".
-    $main::Glade_Perl_Generate_options->source_LANG."/LC_MESSAGES/".$project->{'name'}.".mo)
+    $Glade_Perl->{'options'}->source_LANG."/LC_MESSAGES/".$project->{'name'}.".mo)
 #${indent}\$class->load_translations('$project->{'name'}', 'test', undef, ".
     "'$project->{'directory'}/ppo/$project->{'name'}.mo');\n";
-    if ($main::Glade_Perl_Generate_options->{'allow_gnome'}) {
+    if ($Glade_Perl->{'options'}->{'allow_gnome'}) {
         $init_string .= "${indent}Gnome->init('$project->{'name'}', '$project->{'version'}');";
         $use_string .="\n${indent}# ".
                         S_("We need the Gnome bindings as well").
@@ -542,18 +653,25 @@ ${indent}# ".S_("installed in the normal place")." (eg /usr/local/share/locale/"
     $module = $project->{'name'};
     # remove double spaces
     $isa_string =~ s/  / /g;
-# FIXME I18N
+
 return $class->perl_preamble($module, $project, $proto, $name, undef).
 "BEGIN {
 ${indent}# ".S_("Run-time utilities and vars")."
 ${indent}use Glade::PerlRun; 
 ${indent}# ".S_("Existing signal handler modules")."${use_string}
-${indent}use vars        qw( \@ISA \$AUTOLOAD \%fields \%stubs);
+${indent}use vars qw( 
+${indent}             \@ISA
+${indent}             \%fields
+${indent}             \%stubs
+${indent}             \$VERSION
+${indent}             \$AUTOLOAD
+${indent}         );
 ${indent}# ".S_("Tell interpreter who we are inheriting from")."
-${indent}\@ISA          = qw( $isa_string );
-}
+${indent}\@ISA     = qw( $isa_string );
+${indent}\$VERSION = '$project->{'version'}';
+} # ".S_("End of sub")." BEGIN
 
-${indent}\$Glade::PerlRun::pixmaps_directory ||= '$Glade_Perl->{'glade_proto'}{'project'}{'pixmaps_directory'}';
+${indent}\$Glade::PerlRun::pixmaps_directory ||= '$Glade_Perl->{'options'}{'glade_proto'}{'project'}{'pixmaps_directory'}';
 
 %fields = (
 ${indent}# ".S_("These are the data fields that you can set/get using the dynamic")."
@@ -581,13 +699,13 @@ $permitted_stubs
 sub AUTOLOAD {
 ${indent}my \$self = shift;
 ${indent}my \$type = ref(\$self)
-${indent}${indent}or die \"\$self \"._(\"is not an object so we cannot\").\" '\$AUTOLOAD'\\n\",
-${indent}${indent}${indent}_(\"We were called from \"),join(\", \", caller),\"\\n\\n\";
+${indent}${indent}or die \"\$self is not an object so we cannot '\$AUTOLOAD'\\n\",
+${indent}${indent}${indent}\"We were called from \".join(\", \", caller).\"\\n\\n\";
 ${indent}my \$name = \$AUTOLOAD;
 ${indent}\$name =~ s/.*://;       # ".S_("strip fully-qualified portion")."
 
 ${indent}if (exists \$self->{_permitted_fields}->{\$name} ) {
-${indent}${indent}# ".S_("This allows dynamic data methods - see \%fields above")."
+${indent}${indent}# ".S_("This allows dynamic data methods - see hash fields above")."
 ${indent}${indent}# eg \$class->UI('".S_("new_value")."');
 ${indent}${indent}# or \$current_value = \$class->UI;
 ${indent}${indent}if (\@_) {
@@ -597,7 +715,7 @@ ${indent}${indent}${indent}return \$self->{\$name};
 ${indent}${indent}}
 
 ${indent}} elsif (exists \$stubs{\$name} ) {
-${indent}${indent}# ".S_("This shows dynamic signal handler stub message_box - see \%stubs above")."
+${indent}${indent}# ".S_("This shows dynamic signal handler stub message_box - see hash stubs above")."
 ${indent}${indent}__PACKAGE__->show_skeleton_message(
 ${indent}${indent}${indent}\$AUTOLOAD.\"\\n (\"._(\"AUTOLOADED by\").\" \".__PACKAGE__.\")\", 
 ${indent}${indent}${indent}\[\$self, \@_], 
@@ -605,11 +723,11 @@ ${indent}${indent}${indent}__PACKAGE__,
 ${indent}${indent}${indent}'$project->{'logo'}');
 ${indent}${indent}
 ${indent}} else {
-${indent}${indent}die _(\"Can't access method\").\" `\$name' \"._(\"in class\").\" \$type\\n\",
-${indent}${indent}${indent}_(\"We were called from\").\" \",join(\", \", caller),\"\\n\\n\";
+${indent}${indent}die \"Can't access method\ `\$name' in class \$type\\n\".
+${indent}${indent}${indent}\"We were called from \".join(\", \", caller).\"\\n\\n\";
 
 ${indent}}
-}
+} # ".S_("End of sub")." AUTOLOAD
 
 sub run {
 ${indent}my (\$class) = \@_;
@@ -617,7 +735,7 @@ $init_string
 ${indent}my \$window = \$class->new;
 ${indent}\$window->TOPLEVEL->show;
 ${indent}Gtk->main;
-}
+} # ".S_("End of sub")." run
 
 sub new {
 #
@@ -647,12 +765,12 @@ sub write_SIGS {
     unless (fileno SIGS) {            # ie user has supplied a filename
         # Open SIGS for output unless the filehandle is already open 
         open SIGS,     ">".($proto->{'SIGS_filename'})    or 
-            die sprintf(S_(
+            die sprintf((
                 "error %s - can't open file '%s' for output"),
                 $me, $proto->{'SIGS_filename'});
         $class->diag_print (2, "%s- Writing %s source to %s - in %s",
             $indent, 'SIGS', $proto->{'SIGS_filename'}, $me);
-        if ($main::Glade_Perl_Generate_options->autoflush) {
+        if ($Glade_Perl->{'options'}->autoflush) {
             SIGS->autoflush(1);
         }
     }
@@ -661,15 +779,12 @@ sub write_SIGS {
             $indent, $autosubs, $me);
 
     $form = $first_form;
-# FIXME I18N
     $class->diag_print(4, "%s- Writing %s for class %s", 
         $indent, 'SIGS', $form);
     $permitted_stubs = '';
-#$class->diag_print(2, $proto);
     foreach $form (keys %$forms) {
         push @code, $class->perl_SIGS_top(
-            $Glade_Perl, $proto, $form, $permitted_stubs);
-# FIXME I18N
+            $Glade_Perl->{'options'}, $proto, $form, $permitted_stubs);
         push @code,  "
 #==============================================================================
 #=== ".S_("Below are the signal handlers for")." '$form' class 
@@ -684,7 +799,6 @@ sub write_SIGS {
     }
 
     print SIGS "#!/usr/bin/perl -w\n";
-# FIXME I18N
     print SIGS "#
 # ".S_("This is the (re)generated signal handler class")."
 # ".S_("You can cut and paste the skeleton signal handler subs from this file")."
@@ -692,30 +806,28 @@ sub write_SIGS {
     print SIGS $class->warning;
     print SIGS join("\n", @code);
     print SIGS $class->perl_doc(
-        $Glade_Perl, $proto->{'SIGS_class'}, $first_form);
+        $Glade_Perl->{'options'}, $proto->{'SIGS_class'}, $first_form);
     close SIGS; # flush buffers
 
     unless (-f $proto->{'APP_filename'}) {
         open SIGS,     ">".($proto->{'APP_filename'})    or 
-            die sprintf(S_(
+            die sprintf((
                 "error %s - can't open file '%s' for output"),
                 $me, $proto->{'APP_filename'});
-# FIXME I18N
         $class->diag_print(4, "%s- Creating %s file %s",
             $indent, 'app', $proto->{'APP_filename'});
         $class->diag_print (2, "%s- Writing %s to %s - in %s",
             $indent, 'App', $proto->{'APP_filename'}, $me);
-        if ($main::Glade_Perl_Generate_options->autoflush) {
+        if ($Glade_Perl->{'options'}->autoflush) {
             SIGS->autoflush(1);
         }
         print SIGS "#!/usr/bin/perl -w\n";
-# FIXME I18N
         print SIGS "#
 # ".S_("This is the basis of an application with signal handlers")."\n";
         print SIGS $class->warning('OKTOEDIT');
         print SIGS join("\n", @code);
         print SIGS $class->perl_doc(
-            $Glade_Perl, $proto->{'APP_class'}, $first_form);
+            $Glade_Perl->{'options'}, $proto->{'APP_class'}, $first_form);
     }
 }
 
@@ -740,7 +852,7 @@ sub perl_SIGS_top {
         $use_string .= "\n${indent}use $module;";
 #        $isa_string .= " $module";
     }
-    if ($main::Glade_Perl_Generate_options->{'allow_gnome'}) {
+    if ($Glade_Perl->{'options'}->{'allow_gnome'}) {
         $use_string .="\n${indent}# ".S_("We need the Gnome bindings as well")."\n".
                         "${indent}use Gnome;";
         $init_string .= "${indent}Gnome->init('$project->{'name'}', '$project->{'version'}');";
@@ -753,7 +865,7 @@ sub perl_SIGS_top {
 return $class->perl_preamble($module, $project, $proto, "$name").
 "BEGIN {
 $use_string
-}
+} # ".S_("End of sub")." BEGIN
 
 #===============================================================================
 #=== ".S_("Below are the default signal handlers for")." '$name' class
@@ -763,7 +875,7 @@ $about_string
 sub destroy_Form {
 ${indent}my (\$class, \$data, \$object, \$instance) = \@_;
 ${indent}Gtk->main_quit; 
-}
+} # ".S_("End of sub")." destroy_Form
 
 sub toplevel_hide    { shift->get_toplevel->hide    }
 sub toplevel_close   { shift->get_toplevel->close   }
@@ -783,16 +895,15 @@ sub write_SUBCLASS {
     my ($handler, $module, $form );
     unless (fileno SUBCLASS) {            # ie user has supplied a filename
         open SUBCLASS,     ">".($proto->{'SUBAPP_filename'})    or 
-            die sprintf(S_(
+            die sprintf((
                 "error %s - can't open file '%s' for output"),
                 $me, $proto->{'SUBAPP_filename'});
-# FIXME I18N
         $class->diag_print(4, 
             "%s- Creating %s file %s",
             $indent, 'App Subclass', $proto->{'SUBAPP_filename'});
         $class->diag_print (2, "%s- Writing %s to %s - in %s",
             $indent, 'Subclass', $proto->{'SUBCLASS_filename'}, $me);
-        if ($main::Glade_Perl_Generate_options->autoflush) {
+        if ($Glade_Perl->{'options'}->autoflush) {
             SUBCLASS->autoflush(1);
         }
     }
@@ -809,8 +920,7 @@ sub write_SUBCLASS {
 #        $project, $proto, $form, $permitted_stubs)."\n";
     foreach $form (keys %$forms) {
         push @code, $class->perl_SUBCLASS_top(
-            $Glade_Perl, $proto, $form, $permitted_stubs);
-# FIXME I18N
+            $Glade_Perl->{'options'}, $proto, $form, $permitted_stubs);
         push @code, "
 #==============================================================================
 #=== ".S_("Below are (overloaded) signal handlers for")." '$form' class 
@@ -824,7 +934,7 @@ sub write_SUBCLASS {
         push @code, "\n\n\n\n\n\n\n\n";
     }
     push @code, $class->perl_doc(
-        $Glade_Perl, $proto->{'SUBAPP_class'}, "Sub".$first_form);
+        $Glade_Perl->{'options'}, $proto->{'SUBAPP_class'}, "Sub".$first_form);
 
     print SUBCLASS "#!/usr/bin/perl -w\n";
     print SUBCLASS "#
@@ -852,7 +962,7 @@ sub perl_SUBCLASS_top {
         $use_string .= "\n${indent}use $module;";
         $isa_string .= " $module";
     }
-    if ($main::Glade_Perl_Generate_options->{'allow_gnome'}) {
+    if ($Glade_Perl->{'options'}->{'allow_gnome'}) {
         $use_string .="\n${indent}# ".S_("We need the Gnome bindings as well")."\n".
                         "${indent}use Gnome;";
         $init_string .= "${indent}Gnome->init('$project->{'name'}', '$project->{'version'}');";
@@ -864,20 +974,26 @@ sub perl_SUBCLASS_top {
 # FIXME I18N
 return $class->perl_preamble($module, $project, $proto, "Sub$name").
 "BEGIN {
-${indent}use vars    qw( 
-${indent}                 \@ISA
-${indent}                 \%fields
-${indent}             );
-${indent}# Existing signal handler modules${use_string}
-${indent}# Tell interpreter who we are inheriting from
-${indent}\@ISA      = qw( $name );
-${indent}# Inherit the AUTOLOAD dynamic methods from $name
+${indent}use vars qw( 
+${indent}             \@ISA
+${indent}             \%fields
+${indent}             \$VERSION
+${indent}         );
+${indent}# ".S_("Existing signal handler modules")."${use_string}
+${indent}# ".S_("Uncomment the line below to enable gettext checking")."
+#${indent}use Glade::PerlSource;
+${indent}# ".S_("Tell interpreter who we are inheriting from")."
+${indent}\@ISA     = qw( $name );
+${indent}# ".S_("Uncomment the line below to enable gettext checking")."
+#${indent}\@ISA      = qw( $name Glade::PerlSource );
+${indent}\$VERSION = '$project->{'version'}';
+${indent}# ".S_("Inherit the AUTOLOAD dynamic methods from")." $name
 ${indent}*AUTOLOAD = \\\&$name\::AUTOLOAD;
-}
+} # ".S_("End of sub")." BEGIN
 
 \%fields = (
-# Insert any extra data access methods that you want to add to 
-#   our inherited super-constructor (or overload)
+# ".S_("Insert any extra data access methods that you want to add to")." 
+#   ".S_("our inherited super-constructor (or overload)")."
 ${indent}USERDATA    => undef,
 ${indent}VERSION     => '0.01',
 );
@@ -887,27 +1003,29 @@ ${indent}VERSION     => '0.01',
 #==============================================================================
 sub new {
 ${indent}my \$that  = shift;
-${indent}# Allow indirect constructor so that we can call eg. 
+${indent}# ".S_("Allow indirect constructor so that we can call eg. ")."
 ${indent}#   \$window1 = BusFrame->new; \$window2 = \$window1->new;
 ${indent}my \$class = ref(\$that) || \$that;
 
-${indent}# Call our super-class constructor to get an object and reconsecrate it
+${indent}# ".S_("Call our super-class constructor to get an object and reconsecrate it")."
 ${indent}my \$self = bless \$that->SUPER::new(), \$class;
 
-${indent}# Add our own data access methods to the inherited constructor
+${indent}# ".S_("Add our own data access methods to the inherited constructor")."
 ${indent}my(\$element);
 ${indent}foreach \$element (keys \%fields) {
 ${indent}${indent}\$self->{_permitted_fields}->{\$element} = \$fields{\$element};
 ${indent}}
 ${indent}\@{\$self}{keys \%fields} = values \%fields;
 ${indent}return \$self;
-}
+} # ".S_("End of sub")." new
 
 sub run {
 ${indent}my (\$class) = \@_;
 $init_string
+${indent}# ".S_("Uncomment the line below to enable gettext checking")."
+#${indent}\$class->check_gettext_strings;
 ${indent}my \$window = \$class->new;
-${indent}# Insert your subclass user data key/value pairs 
+${indent}# ".S_("Insert your subclass user data key/value pairs ")."
 ${indent}\$window->USERDATA({
 #${indent}${indent}'Key1'   => 'Value1',
 #${indent}${indent}'Key2'   => 'Value2',
@@ -917,8 +1035,10 @@ ${indent}\$window->TOPLEVEL->show;
 #${indent}my \$window2 = \$window->new;
 #${indent}\$window2->TOPLEVEL->show;
 ${indent}Gtk->main;
+${indent}# ".S_("Uncomment the line below to enable gettext checking")."
+#${indent}\$window->write_gettext_strings(\"__\", '$project->{'POT_filename'}');
 ${indent}return \$window;
-}
+} # ".S_("End of sub")." run
 #===============================================================================
 #=== ".S_("Below are (overloaded) default signal handlers for")." '$name' class 
 #===============================================================================
@@ -927,7 +1047,7 @@ $about_string
 sub destroy_Form {
 ${indent}my (\$class, \$data, \$object, \$instance) = \@_;
 ${indent}Gtk->main_quit; 
-}
+} # ".S_("End of sub")." destroy_Form
 
 sub toplevel_hide    { shift->get_toplevel->hide    }
 sub toplevel_close   { shift->get_toplevel->close   }
@@ -948,8 +1068,8 @@ sub write_LIBGLADE {
     unless (fileno LIBGLADE) {            # ie user has supplied a filename
         # Open LIBGLADE for output unless the filehandle is already open 
         open LIBGLADE,     ">".($proto->{'LIBGLADE_filename'})    or 
-            die sprintf(S_(
-                "error %s - can't open file '%s' for output"),
+            die sprintf(
+                "error %s - can't open file '%s' for output",
                 $me, $proto->{'LIBGLADE_filename'});
     }
     $autosubs &&
@@ -962,7 +1082,7 @@ sub write_LIBGLADE {
     $permitted_stubs = '';
     # FIXME Now generate different source code for each user choice
     push @code, $class->perl_LIBGLADE_top(
-        $Glade_Perl, $proto, $form, $permitted_stubs)."\n";
+        $Glade_Perl->{'options'}, $proto, $form, $permitted_stubs)."\n";
 #    push @code, $class->perl_LIBGLADE_AUTOLOAD_new_bottom($project, $form);
     foreach $form (keys %$forms) {
     push @code, "
@@ -977,10 +1097,10 @@ sub write_LIBGLADE {
         }
     }
     push @code, $class->perl_doc(
-        $Glade_Perl, $proto->{'LIBGLADE_class'}, $proto->{'LIBGLADE_class'});
+        $Glade_Perl->{'options'}, $proto->{'LIBGLADE_class'}, $proto->{'LIBGLADE_class'});
 
     open LIBGLADE,     ">".($proto->{'LIBGLADE_filename'})    or 
-        die sprintf(S_(
+        die sprintf((
             "error %s - can't open file '%s' for output"),
             $me, $proto->{'LIBGLADE_filename'});
     $class->diag_print(2, 
@@ -988,10 +1108,10 @@ sub write_LIBGLADE {
         $indent, 'libglade app', $proto->{'LIBGLADE_filename'});
     $class->diag_print (2, "%s- Writing %s source to %s - in %s",
         $indent, 'LIBGLADE App', $proto->{'LIBGLADE_filename'}, $me);
-    LIBGLADE->autoflush(1) if $main::Glade_Perl_Generate_options->autoflush;
+    LIBGLADE->autoflush(1) if $Glade_Perl->{'options'}->autoflush;
 
     print LIBGLADE "#!/usr/bin/perl -w\n";
-    print LIBGLADE S_("#\n# ".S_("This is the basis of a LIBGLADE application with signal handlers")."\n");
+    print LIBGLADE "#\n# ".S_("This is the basis of a LIBGLADE application with signal handlers")."\n";
     print LIBGLADE $class->warning('OKTOEDIT');
     print LIBGLADE join("\n", @code);
     close LIBGLADE;
@@ -1013,7 +1133,7 @@ ${indent}use Gtk::GladeXML;";
         $use_string .= "\n${indent}use $module;";
         $isa_string .= " $module";
     }
-    if ($main::Glade_Perl_Generate_options->{'allow_gnome'}) {
+    if ($Glade_Perl->{'options'}->{'allow_gnome'}) {
         $use_string .="\n${indent}# ".S_("We need the Gnome bindings as well")."\n".
                         "${indent}use Gnome;";
         $init_string .= "
@@ -1032,21 +1152,23 @@ ${indent}Gtk::GladeXML->init();";
 # FIXME I18N
 return $class->perl_preamble($module, $project, $proto, $project->{'LIBGLADE_class'}, undef).
 "BEGIN {
-${indent}use vars    qw( 
-${indent}                 \@ISA
-${indent}                 \$AUTOLOAD
-${indent}                 \%fields
+${indent}use vars qw( 
+${indent}             \@ISA
+${indent}             \%fields
+${indent}             \$AUTOLOAD
+${indent}             \$VERSION
 ${indent}             );
+${indent}\$VERSION = '$project->{'version'}';
 $use_string
-${indent}# Tell interpreter who we are inheriting from
-${indent}\@ISA      = qw( Glade::PerlRun Gtk::GladeXML);
-}
+${indent}# ".S_("Tell interpreter who we are inheriting from")."
+${indent}\@ISA     = qw( Glade::PerlRun Gtk::GladeXML);
+} # ".S_("End of sub")." BEGIN
 
-${indent}\$Glade::PerlRun::pixmaps_directory ||= '$Glade_Perl->{'glade_proto'}{'project'}{'pixmaps_directory'}';
+${indent}\$Glade::PerlRun::pixmaps_directory ||= '$Glade_Perl->{'options'}{'glade_proto'}{'project'}{'pixmaps_directory'}';
 
 \%fields = (
-# Insert any extra data access methods that you want to add to 
-#   our inherited super-constructor (or overload)
+# ".S_("Insert any extra data access methods that you want to add to")."
+#   ".S_("our inherited super-constructor (or overload)")."
 ${indent}USERDATA    => undef,
 ${indent}VERSION     => '0.01',
 );
@@ -1056,21 +1178,25 @@ ${indent}VERSION     => '0.01',
 #==============================================================================
 sub new {
 ${indent}my \$that  = shift;
-${indent}# Allow indirect constructor so that we can call eg. 
+${indent}# ".S_("Allow indirect constructor so that we can call eg.")."
 ${indent}#   \$window1 = BusFrame->new; \$window2 = \$window1->new;
 ${indent}my \$class = ref(\$that) || \$that;
 
-${indent}# Call Gtk::GladeXML to get an object and reconsecrate it
-${indent}my \$self = bless new Gtk::GladeXML('$project->{'glade_filename'}', '$first_form'), \$class;
+${indent}my \$glade_file = '$project->{'glade_filename'}';
+${indent}unless (-f \$glade_file) {
+${indent}${indent}die \"Unable to find Glade file '\$glade_file'\";
+${indent}}
+${indent}# ".S_("Call Gtk::GladeXML to get an object and reconsecrate it")."
+${indent}my \$self = bless new Gtk::GladeXML(\$glade_file, '$first_form'), \$class;
 
-${indent}# Add our own data access methods to the inherited constructor
+${indent}# ".S_("Add our own data access methods to the inherited constructor")."
 ${indent}my(\$element);
 ${indent}foreach \$element (keys \%fields) {
 ${indent}${indent}\$self->{_permitted_fields}->{\$element} = \$fields{\$element};
 ${indent}}
 ${indent}\@{\$self}{keys \%fields} = values \%fields;
 ${indent}return \$self;
-}
+} # ".S_("End of sub")." new
 
 sub run {
 ${indent}my (\$class) = \@_;
@@ -1080,7 +1206,7 @@ ${indent}\$window->signal_autoconnect_from_package('$project->{'LIBGLADE_class'}
 
 ${indent}Gtk->main;
 ${indent}return \$window;
-}
+} # ".S_("End of sub")." run
 #===============================================================================
 #=== ".S_("Below are the default signal handlers for")." '$name' class 
 #===============================================================================
@@ -1089,7 +1215,7 @@ $about_string
 sub destroy_Form {
 ${indent}my (\$class, \$data, \$object, \$instance) = \@_;
 ${indent}Gtk->main_quit; 
-}
+} # ".S_("End of sub")." destroy_Form
 
 sub toplevel_hide    { shift->get_toplevel->hide    }
 sub toplevel_close   { shift->get_toplevel->close   }
